"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isDoubleUnderline = exports.isBuiltInScalar = void 0;
const scalars = {
    'Boolean': 'Boolean',
    'Float': 'Float',
    'ID': 'ID',
    'Int': 'Int',
    'String': 'String',
};
/**
 * Checks whether a given GraphQL type name is a built-in scalar type.
 * @see https://spec.graphql.org/October2021/#sec-Scalars
 * @example
 * isBuiltInScalar('String') // true
 */
const isBuiltInScalar = (typeName) => Object.values(scalars).includes(typeName);
exports.isBuiltInScalar = isBuiltInScalar;
/**
 * Checks whether a given GraphQL type name is a starting with double underline.
 * @example
 * isDoubleUnderline('__Schema') // true
 */
const isDoubleUnderline = (typeName) => typeName.startsWith('__');
exports.isDoubleUnderline = isDoubleUnderline;
